@@ -122,3 +122,12 @@ class CrudBase:
         self.session.delete(obj)
         self.session.commit()
         return obj
+
+    def delete_all(self):
+        try:
+            num_rows_deleted = self.session.query(self.orm_model).delete()
+            self.session.commit()
+            print("deleted " + str(num_rows_deleted) + " rows from " + self.orm_model.__tablename__)
+        except Exception as ex:
+            print("could not delete rows" + str(ex))
+            self.session.rollback()
